@@ -4,6 +4,7 @@ Utility to easily select lines from the history and execute them again.
 `create_history_application` creates an `Application` instance that runs will
 run as a sub application of the Repl/PythonInput.
 """
+
 from __future__ import annotations
 
 from functools import partial
@@ -410,7 +411,7 @@ class HistoryMapping:
 
         if len(history_strings) > HISTORY_COUNT:
             history_lines[0] = (
-                "# *** History has been truncated to %s lines ***" % HISTORY_COUNT
+                f"# *** History has been truncated to {HISTORY_COUNT} lines ***"
             )
 
         self.history_lines = history_lines
